# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ..common import objects_pb2 as objects__pb2
from ..common import task_status_pb2 as task__status__pb2
from ..common import tasks_common_pb2 as tasks__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13tasks_service.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x11task_status.proto\x1a\x12tasks_common.proto2\xa3\x04\n\x05Tasks\x12h\n\tListTasks\x12+.armonik.api.grpc.v1.tasks.ListTasksRequest\x1a,.armonik.api.grpc.v1.tasks.ListTasksResponse\"\x00\x12\x62\n\x07GetTask\x12).armonik.api.grpc.v1.tasks.GetTaskRequest\x1a*.armonik.api.grpc.v1.tasks.GetTaskResponse\"\x00\x12n\n\x0b\x43\x61ncelTasks\x12-.armonik.api.grpc.v1.tasks.CancelTasksRequest\x1a..armonik.api.grpc.v1.tasks.CancelTasksResponse\"\x00\x12k\n\nCountTasks\x12,.armonik.api.grpc.v1.tasks.CountTasksRequest\x1a-.armonik.api.grpc.v1.tasks.CountTasksResponse\"\x00\x12o\n\x0cGetResultIds\x12..armonik.api.grpc.v1.tasks.GetResultIdsRequest\x1a/.armonik.api.grpc.v1.tasks.GetResultIdsResponseB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Tasksb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Tasks'
  _TASKS._serialized_start=138
  _TASKS._serialized_end=685
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: submitter_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import objects_pb2 as objects__pb2
from ..common import result_status_pb2 as result__status__pb2
from ..common import session_status_pb2 as session__status__pb2
from ..common import submitter_common_pb2 as submitter__common__pb2
from ..common import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17submitter_service.proto\x12\x1d\x61rmonik.api.grpc.v1.submitter\x1a\robjects.proto\x1a\x13result_status.proto\x1a\x14session_status.proto\x1a\x16submitter_common.proto\x1a\x11task_status.proto2\x99\r\n\tSubmitter\x12Y\n\x17GetServiceConfiguration\x12\x1a.armonik.api.grpc.v1.Empty\x1a\".armonik.api.grpc.v1.Configuration\x12w\n\rCreateSession\x12\x33.armonik.api.grpc.v1.submitter.CreateSessionRequest\x1a\x31.armonik.api.grpc.v1.submitter.CreateSessionReply\x12I\n\rCancelSession\x12\x1c.armonik.api.grpc.v1.Session\x1a\x1a.armonik.api.grpc.v1.Empty\x12y\n\x10\x43reateSmallTasks\x12\x35.armonik.api.grpc.v1.submitter.CreateSmallTaskRequest\x1a..armonik.api.grpc.v1.submitter.CreateTaskReply\x12{\n\x10\x43reateLargeTasks\x12\x35.armonik.api.grpc.v1.submitter.CreateLargeTaskRequest\x1a..armonik.api.grpc.v1.submitter.CreateTaskReply(\x01\x12W\n\tListTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1f.armonik.api.grpc.v1.TaskIdList\x12j\n\x0cListSessions\x12,.armonik.api.grpc.v1.submitter.SessionFilter\x1a,.armonik.api.grpc.v1.submitter.SessionIdList\x12S\n\nCountTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1a.armonik.api.grpc.v1.Count\x12\x66\n\x12TryGetResultStream\x12\".armonik.api.grpc.v1.ResultRequest\x1a*.armonik.api.grpc.v1.submitter.ResultReply0\x01\x12W\n\x10TryGetTaskOutput\x12&.armonik.api.grpc.v1.TaskOutputRequest\x1a\x1b.armonik.api.grpc.v1.Output\x12p\n\x13WaitForAvailability\x12\".armonik.api.grpc.v1.ResultRequest\x1a\x30.armonik.api.grpc.v1.submitter.AvailabilityReply\"\x03\x88\x02\x01\x12[\n\x11WaitForCompletion\x12*.armonik.api.grpc.v1.submitter.WaitRequest\x1a\x1a.armonik.api.grpc.v1.Count\x12T\n\x0b\x43\x61ncelTasks\x12).armonik.api.grpc.v1.submitter.TaskFilter\x1a\x1a.armonik.api.grpc.v1.Empty\x12w\n\rGetTaskStatus\x12\x33.armonik.api.grpc.v1.submitter.GetTaskStatusRequest\x1a\x31.armonik.api.grpc.v1.submitter.GetTaskStatusReply\x12\x82\x01\n\x0fGetResultStatus\x12\x35.armonik.api.grpc.v1.submitter.GetResultStatusRequest\x1a\x33.armonik.api.grpc.v1.submitter.GetResultStatusReply\"\x03\x88\x02\x01\x12w\n\x0cWatchResults\x12\x31.armonik.api.grpc.v1.submitter.WatchResultRequest\x1a\x30.armonik.api.grpc.v1.submitter.WatchResultStream(\x01\x30\x01\x42 \xaa\x02\x1d\x41rmoniK.Api.gRPC.V1.Submitterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'submitter_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\035ArmoniK.Api.gRPC.V1.Submitter'
  _SUBMITTER.methods_by_name['WaitForAvailability']._options = None
  _SUBMITTER.methods_by_name['WaitForAvailability']._serialized_options = b'\210\002\001'
  _SUBMITTER.methods_by_name['GetResultStatus']._options = None
  _SUBMITTER.methods_by_name['GetResultStatus']._serialized_options = b'\210\002\001'
  _SUBMITTER._serialized_start=160
  _SUBMITTER._serialized_end=1849
# @@protoc_insertion_point(module_scope)
